/// <reference path="../../../src/types.d.ts" />
import React, { PureComponent } from 'react';
import { Drag } from '../Month';
import { CalcFocusDateProps } from '../../utils';
import ReactList from 'react-list';
import { Locale } from 'date-fns';
import { ClassNames } from '../../styles';
import { AriaLabelShape, CalendarDirection, CalendarFocus, CommonCalendarProps, DateOptions, DisplayMode, PreviewRange, MaybeEmptyRange, RangeFocus, ScrollOptions, SureStartSureEndDate, ClearPreview } from '../../types';
import { DateOrClearReceivingFunc, DateReceivingFunc } from '../DayCell';
declare type ScrollArea = {
    enabled: boolean;
    monthHeight?: number;
    longMonthHeight?: number;
    calendarWidth?: number | 'auto';
    calendarHeight?: number;
    monthWidth?: number;
};
declare type ComponentState = {
    monthNames: string[];
    focusedDate: Date;
    drag: Drag;
    scrollArea: ScrollArea;
    previewRange?: PreviewRange | ClearPreview;
};
declare type DefaultCalendarProps = CalcFocusDateProps & {
    referenceDate: Date;
    ariaLabels?: AriaLabelShape;
    calendarFocus: CalendarFocus;
    classNames: Partial<ClassNames>;
    color: string;
    dateDisplayFormat: string;
    dayDisplayFormat: string;
    direction: CalendarDirection;
    disabledDates: Date[];
    disabledDay: (day: Date) => boolean;
    dragSelectionEnabled: boolean;
    editableDateInputs: boolean;
    endDatePlaceholder: string;
    fixedHeight: boolean;
    focusedRange: RangeFocus;
    locale: Locale;
    maxDate: Date;
    minDate: Date;
    monthDisplayFormat: string;
    months: number;
    preventSnapRefocus: boolean;
    previewRange?: PreviewRange | ClearPreview;
    rangeColors?: string[];
    ranges: MaybeEmptyRange[];
    scroll: {
        enabled: boolean;
    };
    showDateDisplay: boolean;
    showMonthAndYearPickers: boolean;
    showMonthArrow: boolean;
    showPreview: boolean;
    startDatePlaceholder: string;
    weekdayDisplayFormat: string;
    date: Date | number;
};
export declare type CalendarProps = CommonCalendarProps & {
    /** default: today */
    date: Date | number;
    /** default: none */
    onChange?: DateReceivingFunc;
    scroll?: {
        enabled: boolean;
    };
    preventSnapRefocus?: boolean;
    onPreviewChange?: DateOrClearReceivingFunc;
    updateRange?: (range: SureStartSureEndDate) => void;
    className?: string;
    displayMode?: DisplayMode;
};
declare type ComponentProps = CalendarProps & DefaultCalendarProps;
declare class Calendar extends PureComponent<ComponentProps, ComponentState> {
    dateOptions: DateOptions;
    styles: any;
    listSizeCache: any;
    isFirstRender: boolean;
    list: ReactList | null;
    static defaultProps: DefaultCalendarProps;
    static generateDefaultProps(referenceDate?: Date): DefaultCalendarProps;
    constructor(props: ComponentProps);
    getMonthNames(): any[];
    calcScrollArea(props: {
        direction: 'vertical' | 'horizontal';
        months: number;
        scroll: ScrollOptions;
    }): ScrollArea;
    focusToDate: (date: Date, props?: Readonly<ComponentProps> & Readonly<{
        children?: React.ReactNode;
    }>, preventUnnecessary?: boolean) => void;
    updateShownDate: (props?: Readonly<ComponentProps> & Readonly<{
        children?: React.ReactNode;
    }>) => void;
    updatePreview: (val: Date | ClearPreview) => void;
    componentDidMount(): void;
    componentDidUpdate(prevProps: ComponentProps): void;
    changeShownDate: (value: number | string | Date, mode?: string) => void;
    handleRangeFocusChange: (rangesIndex: number, rangeItemIndex: number) => void;
    handleScroll: () => void;
    renderMonthAndYear: (focusedDate: Date, changeShownDate: (n: number | string, method: string) => void, props: ComponentProps) => JSX.Element;
    renderDateDisplay: () => JSX.Element;
    onDragSelectionStart: (date: Date) => void;
    onDragSelectionEnd: (date: Date) => void;
    onDragSelectionMove: (date?: Date | undefined) => void;
    estimateMonthSize: (index: number, cache?: {
        [k: number]: number;
    } | undefined) => number;
    render(): JSX.Element;
}
export default Calendar;
//# sourceMappingURL=index.d.ts.map