var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
import React, { useCallback, useEffect, useState } from 'react';
import Calendar from '../Calendar';
import { findNextRangeIndex, generateStyles, isSelectionComplete } from '../../utils';
import { isBefore, differenceInCalendarDays, addDays, min, isWithinInterval, max, startOfDay, endOfDay } from 'date-fns';
import coreStyles, { DEFAULT_COLOR } from '../../styles';
import { isNoEndDateRange, isNotFullyEmptyRange, isSureRange, IGNORE_PREVIEW, CLEAR_PREVIEW } from '../../types';
import classnames from 'classnames';
import { compose } from 'ramda';
var calculateEndDate = function (value, now, endDate, dayOffset, moveRangeOnFirstSelection, retainEndDateOnFirstSelection, maxDate) {
    var userEndDate = (function () {
        if (moveRangeOnFirstSelection) {
            return addDays(value, dayOffset);
        }
        if (retainEndDateOnFirstSelection) {
            if (!endDate || isBefore(value, endDate)) {
                return endDate;
            }
            return value;
        }
        return value || now;
    })();
    var nextEndDate = maxDate ? (userEndDate ? min([userEndDate, maxDate]) : maxDate) : userEndDate;
    // if (nextEndDate === null) {
    //   throw new Error('Bug! endDate is null, and it should not. RetainEndDateOnFirstSelection tiggers buggy behavior, what should the endDate be now that retainEDFS is true?');
    // }
    return nextEndDate;
};
function computeStartDateEndDate(_a) {
    var value = _a.value, selectedRange = _a.selectedRange, focusedRange = _a.focusedRange, disabledDates = _a.disabledDates, moveRangeOnFirstSelection = _a.moveRangeOnFirstSelection, retainEndDateOnFirstSelection = _a.retainEndDateOnFirstSelection, ranges = _a.ranges, maxDate = _a.maxDate;
    var base = {
        isStartDateSelected: focusedRange[1] === 0,
        focusedRange: focusedRange,
        disabledDates: disabledDates,
        ranges: ranges,
    };
    if (isNotFullyEmptyRange(value)) {
        if (!isSureRange(value)) {
            console.log(value);
            throw new Error('Bug, expecting value to be a SureRange (aka startDate and endDate instanceof Date), but not the case!');
        }
        return __assign(__assign({}, base), { startDate: value.startDate, endDate: value.endDate });
    }
    if (!(value instanceof Date)) {
        console.log(value);
        throw new Error('Probably got a fully empty range, expecting either Date or NotFullyEmptyRange');
    }
    if (isSelectionComplete(focusedRange)) {
        // startDate selection
        var now = new Date();
        var dayOffset = differenceInCalendarDays(selectedRange.endDate || now, selectedRange.startDate);
        return __assign(__assign({}, base), { startDate: value, endDate: calculateEndDate(value, now, selectedRange.endDate, dayOffset, moveRangeOnFirstSelection, retainEndDateOnFirstSelection, maxDate), nextFocusRange: [focusedRange[0], 1] });
    }
    else {
        return __assign(__assign({}, base), { startDate: selectedRange.startDate, endDate: value });
    }
}
var flipIfReversed = function (params) {
    var startDate = params.startDate, endDate = params.endDate, isStartDateSelected = params.isStartDateSelected;
    return endDate && isBefore(endDate, startDate)
        ? __assign(__assign({}, params), { isStartDateSelected: !isStartDateSelected, startDate: startOfDay(endDate), endDate: endOfDay(startDate) }) : __assign(__assign({}, params), { startDate: startOfDay(startDate), endDate: endDate && endOfDay(endDate) });
};
var getNextFocusRange = function (ranges, focusedRange, nextFocusRange) {
    if (nextFocusRange)
        return nextFocusRange;
    var nextFocusRangeIndex = findNextRangeIndex(ranges, focusedRange[0]);
    return [nextFocusRangeIndex, 0];
};
var computeRange = function (_a) {
    var disabledDates = _a.disabledDates, startDate = _a.startDate, endDate = _a.endDate, isStartDateSelected = _a.isStartDateSelected, focusedRange = _a.focusedRange, nextFocusRange = _a.nextFocusRange, ranges = _a.ranges;
    var inValidDatesWithinRange = disabledDates.filter(function (disabledDate) {
        return endDate && isWithinInterval(disabledDate, {
            start: startDate,
            end: endDate,
        });
    });
    var wasValid = !(inValidDatesWithinRange.length > 0);
    var range = {
        startDate: !wasValid && isStartDateSelected
            ? addDays(max(inValidDatesWithinRange), 1)
            : startDate,
        endDate: !wasValid && !isStartDateSelected
            ? addDays(min(inValidDatesWithinRange), -1)
            : endDate,
    };
    return {
        wasValid: wasValid,
        range: range,
        nextFocusRange: getNextFocusRange(ranges, focusedRange, nextFocusRange),
    };
};
var getRes = compose(computeRange, flipIfReversed, computeStartDateEndDate);
export var calcNewSelectionGen = function (props, stateFocusedRange) { return function (value) {
    if (value === IGNORE_PREVIEW || value === CLEAR_PREVIEW)
        return value;
    var focusedRange = props.focusedRange || stateFocusedRange;
    var ranges = props.ranges, onChange = props.onChange, maxDate = props.maxDate, moveRangeOnFirstSelection = props.moveRangeOnFirstSelection, retainEndDateOnFirstSelection = props.retainEndDateOnFirstSelection, disabledDates = props.disabledDates;
    var focusedRangeIndex = focusedRange[0];
    var selectedRange = ranges && ranges[focusedRangeIndex];
    if (!selectedRange || !onChange)
        return IGNORE_PREVIEW;
    if (!isSureRange(selectedRange) && !isNoEndDateRange(selectedRange)) {
        console.log('selectedRange', selectedRange);
        console.log('value', value);
        throw new Error('Bug, expecting selected range to be a sure range or no end date range, but it is neither');
    }
    return getRes({
        value: value,
        selectedRange: selectedRange,
        focusedRange: focusedRange,
        disabledDates: disabledDates || [],
        moveRangeOnFirstSelection: moveRangeOnFirstSelection || false,
        ranges: ranges,
        retainEndDateOnFirstSelection: retainEndDateOnFirstSelection || false,
        maxDate: maxDate,
    });
}; };
var setSelectionGen = function (props, stateFocusedRange, setFocusedRange, setPreview) { return function (value) {
    var _a;
    var onChange = props.onChange, ranges = props.ranges, onRangeFocusChange = props.onRangeFocusChange;
    var focusedRange = props.focusedRange || stateFocusedRange;
    var focusedRangeIndex = focusedRange[0];
    var selectedRange = ranges && ranges[focusedRangeIndex];
    if (!selectedRange)
        return;
    var newSelection = calcNewSelectionGen(props, focusedRange)(value);
    if (!newSelection) {
        throw new Error('Bug, expecting new selection to not be undefined');
    }
    var isSelectionComplete = newSelection.nextFocusRange[1] === 0;
    onChange && onChange((_a = {},
        _a[selectedRange.key || "range" + (focusedRangeIndex + 1)] = __assign(__assign({}, selectedRange), newSelection.range),
        _a), isSelectionComplete);
    setFocusedRange(newSelection.nextFocusRange);
    setPreview(null);
    onRangeFocusChange && onRangeFocusChange(newSelection.nextFocusRange);
}; };
var handleRangeFocusChangeGen = function (setFocusedRange, props) { return function (focusedRange) {
    setFocusedRange(focusedRange);
    props.onRangeFocusChange && props.onRangeFocusChange(focusedRange);
}; };
var updatePreviewGen = function (setPreview, props, stateFocusedRange) { return function (newSelection) {
    var _a;
    if (newSelection === IGNORE_PREVIEW)
        return;
    if (newSelection === CLEAR_PREVIEW) {
        setPreview(null);
        return;
    }
    var rangeColors = props.rangeColors, ranges = props.ranges;
    var focusedRange = props.focusedRange || stateFocusedRange;
    var color = (ranges && ((_a = ranges[focusedRange[0]]) === null || _a === void 0 ? void 0 : _a.color)) || (rangeColors && rangeColors[focusedRange[0]]);
    setPreview(__assign(__assign({}, newSelection.range), { color: color }));
}; };
var composedUpdatePreview = function (setPreview, props, stateFocusedRange) { return function (nextPreviewRangeOrDate) {
    if (nextPreviewRangeOrDate === IGNORE_PREVIEW)
        return;
    var calcNewSelection = calcNewSelectionGen(props, stateFocusedRange);
    var updatePreview = updatePreviewGen(setPreview, props, stateFocusedRange);
    compose(updatePreview, calcNewSelection)(nextPreviewRangeOrDate);
}; };
export var defaultProps = {
    classNames: {},
    ranges: [],
    moveRangeOnFirstSelection: false,
    retainEndDateOnFirstSelection: false,
    rangeColors: [DEFAULT_COLOR, '#3ecf8e', '#fed14c'],
    disabledDates: [],
};
export function getInitialFocusedRange(initialFocusedRange, ranges) {
    return initialFocusedRange || [findNextRangeIndex(ranges || []), 0];
}
var DateRange = function (props) {
    var allProps = __assign(__assign({}, defaultProps), props);
    var initialFocusedRange = allProps.initialFocusedRange, ranges = allProps.ranges, classNames = allProps.classNames, className = allProps.className, nextPreviewRange = allProps.previewRange;
    var _a = __read(useState(getInitialFocusedRange(initialFocusedRange, ranges)), 2), focusedRange = _a[0], setFocusedRange = _a[1];
    var _b = __read(useState(CLEAR_PREVIEW), 2), previewRange = _b[0], setPreviewRange = _b[1];
    var styles = generateStyles([coreStyles, classNames]);
    var setSelection = setSelectionGen(allProps, focusedRange, setFocusedRange, setPreviewRange);
    var handleRangeFocusChange = handleRangeFocusChangeGen(setFocusedRange, allProps);
    var fullUpdatePreview = useCallback(composedUpdatePreview(setPreviewRange, props, focusedRange), [setPreviewRange, props, focusedRange]);
    useEffect(function () {
        if (previewRange === nextPreviewRange)
            return;
        fullUpdatePreview(nextPreviewRange);
    }, [fullUpdatePreview, nextPreviewRange]);
    return (React.createElement(Calendar, __assign({}, allProps, { focusedRange: focusedRange, onRangeFocusChange: handleRangeFocusChange, previewRange: previewRange, onPreviewChange: fullUpdatePreview, displayMode: "dateRange", className: classnames(styles.dateRangeWrapper, className), onChange: setSelection, updateRange: setSelection })));
};
export default DateRange;
