var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import { subDays, addDays, isSameDay } from 'date-fns';
import DateRange, { calcNewSelectionGen, defaultProps, getInitialFocusedRange } from '.';
import renderer from 'react-test-renderer';
import { isSureRange } from '../../types';
import { combineProps } from '../../utils';
var testRenderer;
var endDate = new Date();
var startDate = subDays(endDate, 7);
function getCalcNewSelection(componentProps) {
    var allProps = combineProps(defaultProps, componentProps);
    var calcNewSelection = calcNewSelectionGen(allProps, getInitialFocusedRange(allProps === null || allProps === void 0 ? void 0 : allProps.initialFocusedRange, allProps.ranges));
    return calcNewSelection;
}
var commonProps = {
    ranges: [{ startDate: startDate, endDate: endDate, key: 'selection' }],
    onChange: function () { },
    moveRangeOnFirstSelection: false,
};
var compareRanges = function (assertionRange, newRange) {
    if (!newRange) {
        return expect(typeof newRange).toEqual(typeof assertionRange);
    }
    ['startDate', 'endDate'].forEach(function (key) {
        if (!isSureRange(assertionRange) || !isSureRange(newRange)) {
            return expect(newRange[key]).toEqual(assertionRange[key]);
        }
        return expect(isSameDay(newRange[key], assertionRange[key])).toEqual(true);
    });
};
beforeEach(function () {
    testRenderer = renderer.create(React.createElement(DateRange, __assign({}, commonProps)));
});
describe('DateRange', function () {
    test('Should resolve', function () {
        expect(DateRange).toEqual(expect.anything());
    });
    test('calculate new selection by resetting end date', function () {
        var calcNewSelection = getCalcNewSelection(commonProps);
        var methodResult = calcNewSelection(subDays(endDate, 10));
        compareRanges({
            startDate: subDays(endDate, 10),
            endDate: subDays(endDate, 10),
        }, methodResult === null || methodResult === void 0 ? void 0 : methodResult.range);
    });
    test('calculate new selection by resetting end date if start date is not before', function () {
        var calcNewSelection = getCalcNewSelection(commonProps);
        var methodResult = calcNewSelection(addDays(endDate, 2));
        compareRanges({
            startDate: addDays(endDate, 2),
            endDate: addDays(endDate, 2),
        }, methodResult === null || methodResult === void 0 ? void 0 : methodResult.range);
    });
    test('calculate new selection based on moveRangeOnFirstSelection prop', function () {
        var componentProps = __assign(__assign({}, commonProps), { moveRangeOnFirstSelection: true });
        testRenderer.update(React.createElement(DateRange, __assign({}, componentProps)));
        var calcNewSelection = getCalcNewSelection(componentProps);
        var methodResult = calcNewSelection(subDays(endDate, 10));
        compareRanges({
            startDate: subDays(endDate, 10),
            endDate: subDays(endDate, 3),
        }, methodResult === null || methodResult === void 0 ? void 0 : methodResult.range);
    });
    test('calculate new selection by retaining end date, based on retainEndDateOnFirstSelection prop', function () {
        var componentProps = __assign(__assign({}, commonProps), { retainEndDateOnFirstSelection: true });
        testRenderer.update(React.createElement(DateRange, __assign({}, componentProps)));
        var calcNewSelection = getCalcNewSelection(componentProps);
        var methodResult = calcNewSelection(subDays(endDate, 10));
        compareRanges({
            startDate: subDays(endDate, 10),
            endDate: endDate,
        }, methodResult === null || methodResult === void 0 ? void 0 : methodResult.range);
    });
    test('calculate new selection by retaining the unset end date, based on retainEndDateOnFirstSelection prop', function () {
        var componentProps = __assign(__assign({}, commonProps), { ranges: [__assign(__assign({}, commonProps.ranges[0]), { endDate: null })], retainEndDateOnFirstSelection: true });
        testRenderer.update(React.createElement(DateRange, __assign({}, componentProps)));
        var calcNewSelection = getCalcNewSelection(componentProps);
        var methodResult = calcNewSelection(subDays(endDate, 10));
        compareRanges({
            startDate: subDays(endDate, 10),
            endDate: null,
        }, methodResult === null || methodResult === void 0 ? void 0 : methodResult.range);
    });
});
