var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import React from 'react';
import { mount, shallow } from 'enzyme';
import DefinedRange from '.';
import { getDummyRange, createStaticRanges } from '../../defaultRanges';
function fillUp(sr) {
    return __assign(__assign({}, sr), { range: getDummyRange });
}
describe('DefinedRange tests', function () {
    test('Should call "renderStaticRangeLabel" callback correct amount of times according to the "hasCustomRendering" option', function () {
        var renderStaticRangeLabel = jest.fn();
        var staticRanges = createStaticRanges([
            {
                label: 'Dynamic Label',
                hasCustomRendering: true,
            },
            {
                label: 'Static Label',
            },
            {
                label: 'Hede',
                hasCustomRendering: true,
            },
        ].map(fillUp));
        mount(React.createElement(DefinedRange, { staticRanges: staticRanges, renderStaticRangeLabel: renderStaticRangeLabel }));
        expect(renderStaticRangeLabel).toHaveBeenCalledTimes(2);
    });
    test('Should render dynamic static label contents correctly', function () {
        var renderItalicLabelContent = function () { return (React.createElement("i", { className: 'italic-label-content' }, 'Italic Content')); };
        var renderBoldLabelContent = function () { return React.createElement("b", { className: 'bold-label-content' }, 'Bold Content'); };
        var renderSomethingElse = function () { return React.createElement("img", { className: 'random-image' }); };
        var renderStaticRangeLabel = function (staticRange) {
            var result;
            if (staticRange.id === 'italic') {
                result = renderItalicLabelContent();
            }
            else if (staticRange.id === 'bold') {
                result = renderBoldLabelContent();
            }
            else {
                result = renderSomethingElse();
            }
            return result;
        };
        var wrapper = shallow(React.createElement(DefinedRange, { staticRanges: createStaticRanges([
                {
                    id: 'italic',
                    hasCustomRendering: true,
                },
                {
                    label: 'Static Label',
                },
                {
                    id: 'whatever',
                    hasCustomRendering: true,
                },
                {
                    id: 'bold',
                    hasCustomRendering: true,
                },
            ].map(fillUp)), renderStaticRangeLabel: renderStaticRangeLabel }));
        expect(wrapper).toMatchSnapshot();
    });
});
