import React from 'react';
import { mount } from 'enzyme';
import InputRangeField from '.';
var styles = {
    inputRange: 'range',
    inputRangeInput: 'input',
    inputRangeLabel: 'label',
};
var toChangeEvent = function (value) { return ({ target: { value: value } }); };
describe('InputRangeField tests', function () {
    test('Should parse input value to number', function () {
        var onChange = jest.fn();
        var wrapper = mount(React.createElement(InputRangeField, { label: "Input label", styles: styles, onChange: onChange, onFocus: jest.fn(), onBlur: jest.fn() }));
        wrapper.find('input').simulate('change', toChangeEvent('3'));
        expect(onChange).lastCalledWith(3);
        wrapper.find('input').simulate('change', toChangeEvent(12));
        expect(onChange).lastCalledWith(12);
        wrapper.find('input').simulate('change', toChangeEvent(''));
        expect(onChange).lastCalledWith(0);
        wrapper.find('input').simulate('change', toChangeEvent('invalid number'));
        expect(onChange).lastCalledWith(0);
        wrapper.find('input').simulate('change', toChangeEvent(-12));
        expect(onChange).lastCalledWith(0);
        wrapper.find('input').simulate('change', toChangeEvent(99999999));
        expect(onChange).lastCalledWith(99999);
        expect(onChange).toHaveBeenCalledTimes(6);
        expect(wrapper).toMatchSnapshot();
    });
    test('Should rerender when props change', function () {
        var wrapper = mount(React.createElement(InputRangeField, { value: 12, placeholder: "Placeholder", label: "Input label", styles: styles, onChange: jest.fn(), onFocus: jest.fn(), onBlur: jest.fn() }));
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual(12);
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('Placeholder');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        wrapper.setProps({ value: '32' });
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual('32');
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('Placeholder');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        wrapper.setProps({ placeholder: '-' });
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual('32');
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('-');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        wrapper.setProps({ label: 'Label' });
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual('32');
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('-');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Label');
    });
    test('Should render the label as a Component', function () {
        var Label = function () { return React.createElement("span", { className: "input-range-field-label" }, "Input label"); };
        var wrapper = mount(React.createElement(InputRangeField, { value: 12, placeholder: "Placeholder", label: React.createElement(Label, null), styles: styles, onChange: jest.fn(), onFocus: jest.fn(), onBlur: jest.fn() }));
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual(12);
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('Placeholder');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        expect(wrapper.find(".input-range-field-label").text()).toEqual('Input label');
        wrapper.setProps({ value: '32' });
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual('32');
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('Placeholder');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        wrapper.setProps({ placeholder: '-' });
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual('32');
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('-');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Input label');
        wrapper.setProps({ label: 'Label' });
        expect(wrapper.find("." + styles.inputRangeInput).prop('value')).toEqual('32');
        expect(wrapper.find("." + styles.inputRangeInput).prop('placeholder')).toEqual('-');
        expect(wrapper.find("." + styles.inputRangeLabel).text()).toEqual('Label');
    });
});
