import React from 'react';
import { Locale } from 'date-fns';
import { ClassNames } from './styles';
export declare type AnyDate = string | Date;
export declare type DateOrTimestamp = Date | number;
export declare type DateFunc = (now: Date) => AnyDate;
export declare type DateGen = (now: Date) => Date;
export declare type DateInputType = AnyDate | DateGen;
export declare type LanguageType = 'cn' | 'jp' | 'fr' | 'it' | 'de' | 'ko' | 'es' | 'ru' | 'tr';
export declare type SizeType = number;
export declare type ClearPreview = null;
export declare type IgnorePreview = undefined;
export declare const IGNORE_PREVIEW: IgnorePreview;
export declare const CLEAR_PREVIEW: ClearPreview;
export declare const DEFAULT_DISPLAY_MODE: DisplayMode;
export interface DateContainerType {
    date: Date;
}
export declare type AriaLabelShape = {
    dateInput?: {
        [x: string]: StartEndDate<Date | string>;
    };
    monthPicker?: string;
    yearPicker?: string;
    prevButton?: string;
    nextButton?: string;
};
export interface CalendarTheme {
    DateRange?: React.CSSProperties;
    Calendar?: React.CSSProperties;
    Day?: React.CSSProperties;
    DayPassive?: React.CSSProperties;
    DayHover?: React.CSSProperties;
    DayToday?: React.CSSProperties;
    DaySunday?: React.CSSProperties;
    DaySpecialDay?: React.CSSProperties;
    DayActive?: React.CSSProperties;
    DaySelected?: React.CSSProperties;
    DayStartEdge?: React.CSSProperties;
    DayEndEdge?: React.CSSProperties;
    DayInRange?: React.CSSProperties;
    Weekday?: React.CSSProperties;
    MonthAndYear?: React.CSSProperties;
    MonthButton?: React.CSSProperties;
    MonthArrow?: React.CSSProperties;
    MonthArrowPrev?: React.CSSProperties;
    MonthArrowNext?: React.CSSProperties;
    PredefinedRanges?: React.CSSProperties;
    PredefinedRangesItem?: React.CSSProperties;
    PredefinedRangesItemActive?: React.CSSProperties;
}
export declare type ModeMapper = {
    monthOffset: () => Date;
    setMonth: () => Date;
    setYear: () => Date;
    set: () => number;
};
export declare function isModeMapperKey(s: string, o: ModeMapper): s is keyof ModeMapper;
export interface RangeWithKey extends MaybeEmptyRange {
    key: 'selection';
}
export interface OnDateRangeChangeProps {
    [key: string]: MaybeEmptyRange;
}
export declare type WeekStartsOn = 0 | 1 | 2 | 3 | 4 | 5 | 6;
export declare type DateOptions = {
    locale: Locale;
    weekStartsOn?: WeekStartsOn;
};
export declare function isSureRange<T>(range: MaybeEmptyRange & T): range is SureStartSureEndDate & T;
export interface CommonCalendarProps {
    /** default: DD/MM/YYY */
    format?: string;
    firstDayOfWeek?: number;
    theme?: CalendarTheme;
    /** default: none */
    onInit?: ((range: MaybeEmptyRange) => void);
    /** default: none */
    minDate?: Date;
    /** default: none */
    maxDate?: Date;
    /** default: */
    weekStartsOn?: WeekStartsOn;
    /** default: enUs from locale. Complete list here https://github.com/Adphorus/react-date-range/blob/next/src/locale/index.js */
    locale?: Locale;
    /** Custom class names for elements */
    classNames?: Partial<ClassNames>;
    /** default: none */
    navigatorRenderer?: (currentFocusedDate: Date, changeShownDate: (shownDate: Date) => void, props: CommonCalendarProps) => JSX.Element;
    /** default: none */
    onShownDateChange?: ((visibleMonth: Date) => void);
    /** default: none */
    onRangeFocusChange?: ((focusedRange: RangeFocus) => void);
    /** default: false */
    editableDateInputs?: boolean;
    /** default: true */
    dragSelectionEnabled?: boolean;
    /** default: false */
    fixedHeight?: boolean;
}
export declare type DisplayMode = 'date' | 'dateRange';
export declare type CalendarFocus = 'forwards' | 'backwards';
export declare type CalendarDirection = 'vertical' | 'horizontal';
export interface CalendarProps extends CommonCalendarProps {
    /** default: today */
    date: DateInputType;
    /** default: none */
    onChange?: (date?: Date) => void;
    scroll?: {
        enabled: boolean;
    };
    preventSnapRefocus?: boolean;
    calendarFocus: CalendarFocus;
    months: number;
}
export interface DateRangeProps extends MaybeEmptyRange, CommonCalendarProps {
    /** default: enUs from locale. Complete list here https://github.com/Adphorus/react-date-range/blob/next/src/locale/index.js */
    locale?: Locale;
    /** default: false */
    linkedCalendars?: boolean;
    /** default: 2 */
    calendars?: number;
    /** default: none */
    ranges?: MaybeEmptyRange[];
    /** default: { enabled: false } */
    scroll?: ScrollOptions;
    /** default: false */
    showSelectionPreview?: boolean;
    /** default: false */
    twoStepChange?: boolean;
    /** default: true */
    showMonthArrow?: boolean;
    /** default: false */
    rangedCalendars?: boolean;
    /** default: none */
    specialDays?: DateContainerType[];
    /** default: 1 */
    months?: number;
    /** default: true */
    showMonthAndYearPickers?: boolean;
    /** default: [] */
    rangeColors?: string[];
    /** default: */
    shownDate?: Date;
    /** default: */
    disabledDates?: Date[];
    /** default: */
    disabledDay?: ((date: Date) => boolean);
    /** default: Early */
    startDatePlaceholder?: string;
    /** default: */
    className?: string;
    /** default: Continuous */
    endDatePlaceholder?: string;
    /** default: MMM d, yyyy */
    dateDisplayFormat?: string;
    /** default: d */
    dayDisplayFormat?: string;
    /** default: E */
    weekdayDisplayFormat?: string;
    /** default: MMM yyyy */
    monthDisplayFormat?: string;
    /** default: vertical */
    direction?: CalendarDirection;
    /** default: false */
    moveRangeOnFirstSelection?: boolean;
    /** default: false */
    retainEndDateOnFirstSelection?: boolean;
    /** default: false */
    editableDateInputs?: boolean;
    /** default: */
    focusedRange?: RangeFocus;
    /** default: [0, 0] */
    initialFocusedRange?: RangeFocus;
    /** default: */
    onRangeFocusChange?: ((focusedRange: RangeFocus) => void);
    /** default: */
    previewRange?: PreviewRange | ClearPreview | IgnorePreview;
    /** default: true */
    showPreview?: boolean;
    /** default: */
    onPreviewChange?: (previewRange?: PreviewRange | ClearPreview) => void;
    /** default: none */
    onChange?: OnRangeChangeHandler;
}
export declare type OnRangeChangeHandler = (range: OnDateRangeChangeProps, isComplete?: boolean) => void;
export interface DateRangePickerProps extends DateRangeProps {
    renderStaticRangeLabel?: ((range: DefinedRange) => JSX.Element);
    staticRanges?: StaticRange[];
    inputRanges?: InputRange[];
}
export declare type DateRangeIndex = 'Today' | 'Yesterday' | 'Last 7 Days' | 'Last 30 Days';
export declare type SureStartSureEndDate<D = Date> = {
    startDate: D;
    endDate: D;
};
export declare type SureStartMaybeEndDate<D = Date> = {
    startDate: D;
    endDate: D | null;
};
export declare type SureStartNoEndDate<D = Date> = {
    startDate: D;
    endDate: null;
};
export declare type NotFullyEmptyRange<D = Date> = OtherRangeProps & (SureStartSureEndDate<D> | SureStartMaybeEndDate<D> | SureStartNoEndDate<D>);
export declare function isNoEndDateRange(r: NotFullyEmptyRange): r is SureStartNoEndDate;
export declare type StartEndDate<D = Date> = Partial<SureStartSureEndDate<D>>;
export declare type StartEndDateGen = () => SureStartSureEndDate;
export declare type RangeGen = <T>(props?: T) => NotFullyEmptyRange;
export declare type WithRangeGen = {
    range: RangeGen;
};
export declare type WithRange = {
    range: NotFullyEmptyRange;
};
export declare type WithRangeOrRangeGen = WithRange | WithRangeGen;
export declare type MaybeWithRangeOrRangeGen = Partial<WithRange> | Partial<WithRangeGen>;
export declare function hasRangeGen(wr: WithRangeOrRangeGen): wr is WithRangeGen;
export declare function hasRange(wr: WithRangeOrRangeGen): wr is WithRange;
export declare function isNotFullyEmptyRange(r: any): r is NotFullyEmptyRange;
export declare type LabeledStartEndDateGen = WithRangeGen & {
    label: string;
};
export interface OtherRangeProps {
    color?: string;
    key?: string;
    autoFocus?: boolean;
    disabled?: boolean;
    showDateDisplay?: boolean;
}
export interface SureRange<D = Date> extends SureStartSureEndDate<D>, OtherRangeProps {
}
export interface MaybeEmptyRange<D = Date | null> extends StartEndDate<D>, OtherRangeProps {
}
export interface ScrollOptions {
    enabled: boolean;
    monthHeight?: number;
    longMonthHeight?: number;
    monthWidth?: number;
    calendarWidth?: number;
    calendarHeight?: number;
}
export declare type WithLabel = {
    label: string;
};
export declare type WithMaybeLabel = {
    label?: string;
};
export declare type WithMaybeId = {
    id?: string;
};
export declare type WithIsSelected = {
    isSelected: (range: SureStartSureEndDate) => boolean;
};
export interface DefinedRangeCommon extends WithMaybeLabel, WithMaybeId {
    hasCustomRendering?: boolean;
}
export declare type WithRangeCallback = {
    range: RangeGen;
};
export declare type StaticRange = DefinedRangeCommon & WithRangeOrRangeGen & WithIsSelected;
export interface InputRange {
    range: (value: number, props?: CommonCalendarProps) => SureStartSureEndDate;
    getCurrentValue: (range: MaybeEmptyRange) => number | "-" | "∞";
}
export declare type InputRangeWihLabel = InputRange & WithLabel;
export declare type DefinedRange = StaticRange | InputRange;
/**
 * Represents range focus `[range, rangeElement]`. `range` represents the index of the range
 * that's focused and the `rangeElement` the element of the range that's
 * focused, `0` for start date and `1` for end date
 */
export declare type RangeFocus = [number, number];
export declare type PreviewRange = NotFullyEmptyRange & {
    color?: string;
};
//# sourceMappingURL=types.d.ts.map