var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spreadArray = (this && this.__spreadArray) || function (to, from, pack) {
    if (pack || arguments.length === 2) for (var i = 0, l = from.length, ar; i < l; i++) {
        if (ar || !(i in from)) {
            if (!ar) ar = Array.prototype.slice.call(from, 0, i);
            ar[i] = from[i];
        }
    }
    return to.concat(ar || Array.prototype.slice.call(from));
};
import React from 'react';
import classnames from 'classnames';
import { startOfMonth, endOfMonth, startOfWeek, endOfWeek, differenceInCalendarDays, differenceInCalendarMonths, addDays, eachDayOfInterval, format, } from 'date-fns';
function isDateRangeMode(p) {
    return p.displayMode === 'dateRange';
}
function isDateMode(p) {
    return !isDateRangeMode(p);
}
export function calcFocusDateRangeModeLastPart(currentFocusedDate, months, startInput, endInput, shownDate) {
    var targetInterval = {
        start: startOfMonth(startInput),
        end: endOfMonth(endInput || startInput),
    };
    var targetDate = targetInterval.start || targetInterval.end || shownDate || new Date();
    // initial focus
    if (!currentFocusedDate)
        return shownDate || targetDate;
    // // just return targetDate for native scrolled calendars
    // if (props.scroll.enabled) return targetDate;
    if (differenceInCalendarMonths(targetInterval.start, targetInterval.end) > months) {
        // don't change focused if new selection in view area
        return currentFocusedDate;
    }
    return targetDate;
}
export function calcFocusDateMode(currentFocusedDate, _a) {
    var shownDate = _a.shownDate, date = _a.date, months = _a.months;
    // find primary date according the props
    var startInput = date || new Date();
    var endInput = date;
    return calcFocusDateRangeModeLastPart(currentFocusedDate, months, startInput, endInput, shownDate);
}
export function calcFocusDateRangeMode(currentFocusedDate, props) {
    var shownDate = props.shownDate, months = props.months, ranges = props.ranges, focusedRange = props.focusedRange;
    // find primary date according the props
    var now = new Date();
    var range = (ranges && focusedRange && ranges.length > 0 && ranges[focusedRange[0]]) || {
        startDate: now,
        endDate: now,
    };
    var startInput = range.startDate || new Date();
    var endInput = range.endDate;
    return calcFocusDateRangeModeLastPart(currentFocusedDate, months, startInput, endInput, shownDate);
}
export function calcFocusDate(currentFocusedDate, props) {
    if (isDateRangeMode(props)) {
        return calcFocusDateRangeMode(currentFocusedDate, props);
    }
    else if (isDateMode(props)) {
        return calcFocusDateMode(currentFocusedDate, props);
    }
    else {
        throw new Error('Never happened');
    }
}
export function calcFocusDateBis(currentFocusedDate, props) {
    var shownDate = props.shownDate, months = props.months;
    // find primary date according the props
    var targetInterval;
    if (isDateRangeMode(props)) {
        var range = props.focusedRange && props.ranges[props.focusedRange[0]] || { startDate: undefined, endDate: undefined };
        targetInterval = {
            start: range.startDate,
            end: range.endDate,
        };
    }
    else {
        targetInterval = {
            start: props.date,
            end: props.date,
        };
    }
    targetInterval.start = startOfMonth(targetInterval.start || new Date());
    targetInterval.end = endOfMonth(targetInterval.end || targetInterval.start);
    var targetDate = targetInterval.start || targetInterval.end || shownDate || new Date();
    // initial focus
    if (!currentFocusedDate)
        return shownDate || targetDate;
    // // just return targetDate for native scrolled calendars
    // if (props.scroll.enabled) return targetDate;
    if (differenceInCalendarMonths(targetInterval.start, targetInterval.end) > months) {
        // don't change focused if new selection in view area
        return currentFocusedDate;
    }
    return targetDate;
}
export function findNextRangeIndex(ranges, currentRangeIndex) {
    if (currentRangeIndex === void 0) { currentRangeIndex = -1; }
    var nextIndex = ranges.findIndex(function (range, i) { return i > currentRangeIndex && range.autoFocus !== false && !range.disabled; });
    if (nextIndex !== -1)
        return nextIndex;
    return ranges.findIndex(function (range) { return range.autoFocus !== false && !range.disabled; });
}
export function getMonthDisplayRange(date, dateOptions, fixedHeight) {
    if (fixedHeight === void 0) { fixedHeight = false; }
    var startDateOfMonth = startOfMonth(date);
    var endDateOfMonth = endOfMonth(date);
    var startDateOfCalendar = startOfWeek(startDateOfMonth, dateOptions);
    var endDateOfCalendar = endOfWeek(endDateOfMonth, dateOptions);
    if (fixedHeight && differenceInCalendarDays(endDateOfCalendar, startDateOfCalendar) <= 34) {
        endDateOfCalendar = addDays(endDateOfCalendar, 7);
    }
    return {
        start: startDateOfCalendar,
        end: endDateOfCalendar,
        startDateOfMonth: startDateOfMonth,
        endDateOfMonth: endDateOfMonth,
    };
}
export function renderWeekdays(styles, dateOptions, weekdayDisplayFormat) {
    var now = new Date();
    return (React.createElement("div", { className: styles.weekDays }, eachDayOfInterval({
        start: startOfWeek(now, dateOptions),
        end: endOfWeek(now, dateOptions),
    }).map(function (day, i) { return (React.createElement("span", { className: styles.weekDay, key: i }, format(day, weekdayDisplayFormat, dateOptions))); })));
}
export var logger = {
    log: function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
        console.log.apply(console, __spreadArray([], __read(args), false));
    },
    mute: function () {
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i] = arguments[_i];
        }
    }
};
function isStyleSourceKey(a, k) {
    return a.hasOwnProperty(k);
}
export function isStylesMap(s) {
    return typeof s === 'object';
}
export function augmentStyles(styles, augmentingStyles) {
    return Object.keys(augmentingStyles).reduce(function (styles, key) {
        var _a;
        var alreadyAddedClassNames = styles.hasOwnProperty(key)
            ? styles[key]
            : [];
        return __assign(__assign({}, styles), (_a = {}, _a[key] = classnames(alreadyAddedClassNames, isStyleSourceKey(augmentingStyles, key) ? augmentingStyles[key] : []), _a));
    }, styles);
}
export function generateStyles(sources) {
    var emptyStyles = {};
    if (!sources.length)
        return emptyStyles;
    var generatedStyles = sources
        .filter(isStylesMap)
        .reduce(augmentStyles, emptyStyles);
    return generatedStyles;
}
export function inferAriaLabel(range, ariaLabels, key) {
    if (!ariaLabels) {
        return undefined;
    }
    if (ariaLabels.dateInput && range.key && !ariaLabels.dateInput[range.key]) {
        console.log('range', range);
        console.log('ariaLabels', ariaLabels);
        throw new Error('Range "key" property refering an ariaLabel prop name which does not exist ariaLabels.dateInput[range.key]: string');
    }
    var sd = (ariaLabels.dateInput && range.key
        && ariaLabels.dateInput[range.key]) || ({
        startDate: 'range start date',
        endDate: 'range end date',
    })[key];
    if (sd instanceof Date) {
        return sd.toLocaleString();
    }
    else if (typeof sd === 'string') {
        return sd;
    }
    else {
        console.log(ariaLabels);
        throw new Error('Unsupported ariaLabel type');
    }
}
export function combineProps(base, augmentOverwrite) {
    return __assign(__assign({}, base), augmentOverwrite);
}
export function colorOpacity(color, opacity) {
    var rgbFuncColor = color.replace(')', ", " + opacity + ")");
    if (rgbFuncColor !== color) {
        return rgbFuncColor;
    }
    return color + Math.ceil(opacity * 255).toString(16);
}
export function isSelectionComplete(focusedRange) {
    return focusedRange[1] === 0;
}
