var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
import classnames from "classnames";
import { isValid, subDays } from "date-fns";
import coreStyles from "./styles";
import { calcFocusDate, findNextRangeIndex, generateStyles, getMonthDisplayRange, isStylesMap } from "./utils";
describe('Utils:getMonthDisplayRange', function () {
    test('should have all properties with proper value types', function () {
        var now = new Date();
        var range = getMonthDisplayRange(now, { weekStartsOn: 0 });
        expect(range).toMatchObject({ end: expect.any(Date), endDateOfMonth: expect.any(Date), start: expect.any(Date), startDateOfMonth: expect.any(Date), });
    });
});
describe('Utils:calcFocusDateRangeMode', function () {
    test('should run calcFocusDate in displayMode="date" by default', function () {
        var endDate = new Date();
        var startDate = subDays(endDate, 7);
        var props = {
            shownDate: undefined,
            months: 1,
            ranges: [
                {
                    startDate: startDate,
                    endDate: endDate,
                    key: 'selection'
                }
            ],
            focusedRange: [0, 0]
        };
        var calcDate = calcFocusDate(null, props);
        expect(calcDate).toBeInstanceOf(Date);
        expect(isValid(calcDate)).toBeTruthy();
    });
    test('should run calcFocusDate in displayMode="dateRange" when provided', function () {
        var endDate = new Date();
        var startDate = subDays(endDate, 7);
        var props = {
            displayMode: 'dateRange',
            shownDate: undefined,
            months: 1,
            ranges: [
                {
                    startDate: startDate,
                    endDate: endDate,
                    key: 'selection'
                }
            ],
            focusedRange: [0, 0]
        };
        var calcDate = calcFocusDate(null, props);
        expect(calcDate).toBeInstanceOf(Date);
        expect(isValid(calcDate)).toEqual(true);
    });
});
describe('Utils:findNextRangeIndex', function () {
    test('should get the first range when range.autoFocus and range.disabled is not expliciitely put to "false"', function () {
        var endDate = new Date();
        var startDate = subDays(endDate, 7);
        var ranges = [{ startDate: startDate, endDate: endDate, key: 'selection' }];
        var nextRangeIndex = findNextRangeIndex(ranges);
        expect(nextRangeIndex).toEqual(0);
    });
});
describe('Utils:generateStyles', function () {
    test('should return a coreStyles on empty augmentation', function () {
        var generated = generateStyles([coreStyles, {}]);
        expect(generated).toEqual(coreStyles);
    });
    test('should return a combination of default classes and user classes', function () {
        var augmentation = { dateRangePickerWrapper: "hello" };
        var generated = generateStyles([coreStyles, augmentation]);
        var combined = __assign(__assign({}, coreStyles), { dateRangePickerWrapper: coreStyles.dateRangePickerWrapper + " " + augmentation.dateRangePickerWrapper });
        expect(generated).toEqual(combined);
    });
});
describe('Utils:isStyleMap', function () {
    test('should categorize coreStyles as a stylemap', function () {
        expect(isStylesMap(coreStyles)).toEqual(true);
    });
    test('should deem an empty object as a stylemap', function () {
        expect(isStylesMap({})).toEqual(true);
    });
});
describe('Utils:classnames()', function () {
    test('what does it look like?', function () {
        expect(classnames([], [])).toEqual("");
    });
    test('what does it look like [a] []?', function () {
        expect(classnames(['a'], [])).toEqual("a");
    });
    test('what does it look like [a] [b]?', function () {
        expect(classnames(['a'], ['b'])).toEqual("a b");
    });
    test('what does it look like [a] [b,c]?', function () {
        expect(classnames(['a'], ['b', 'c'])).toEqual("a b c");
    });
    test('what does it look like [a] [b c]?', function () {
        expect(classnames(['a'], ['b c'])).toEqual("a b c");
    });
});
