import React, { useEffect, useState } from 'react';
import DateRange from '../DateRange';
import { DefinedRangeCP } from '../DefinedRange';
import { findNextRangeIndex, generateStyles } from '../../utils';
import classnames from 'classnames';
import coreStyles from '../../styles';
import { ClearPreview, DateRangeProps, IgnorePreview, PreviewRange, RangeFocus } from '../../types';
import StaticRanges from '../StaticRanges';

type ComponentDefaultProps = {
  className?: string;
}
export type DateRangePickerCDP = ComponentDefaultProps;

type ComponentProps = DateRangeProps & DefinedRangeCP & ComponentDefaultProps & {
  collapse?: boolean;
};
export type DateRangePickerCP = ComponentProps;

const defaultProps: ComponentDefaultProps = {
  className: '',
}

const CollapsibleDateRangePicker: React.FC<ComponentProps> = (props) => {

  const allProps: ComponentProps = { ...defaultProps, ...props };
  const { classNames, className, ranges, collapse} = allProps;
  const styles = generateStyles([coreStyles, classNames]);
  const [focusedRange, setFocusedRange] = useState<RangeFocus>((props.ranges && [findNextRangeIndex(props.ranges), 0]) || [0, 0])
  const [collapsed, setCollapsed] = useState(true);
  const usableFocusedRange = allProps.focusedRange || focusedRange;
  const [nextPreviewRange, setNextPreviewRange] = useState<PreviewRange | IgnorePreview | ClearPreview>();
  const onPreviewChange = allProps.onPreviewChange || setNextPreviewRange;

  useEffect(() => {
    if (collapse === undefined) return;
    setCollapsed(collapse);
  }, [setCollapsed, collapse]);

  const cname = classnames(styles.collapsibleCalendarWrapper, className);

  return (
    <div className={[cname, ...(collapsed ? [`${cname}--collapsed`]: [])].join(' ')}>
      <div className={styles.collapsibleCalendarHeader}>
        <StaticRanges
          {...allProps}
          focusedRange={usableFocusedRange}
          onPreviewChange={onPreviewChange}
          // range={this.props.ranges[focusedRange[0]]}
          ranges={ranges} // replaces the single range above (added by g)
        />
        <button className={styles.collapsibleCalendarButton} type="button" onClick={_ => {
          setCollapsed(!collapsed);
        }}><i></i></button>
      </div>
      <div className={styles.collapsibleCalendarBody}>
        <DateRange
          {...allProps}
          onPreviewChange={onPreviewChange}
          previewRange={nextPreviewRange}
          onRangeFocusChange={setFocusedRange}
          focusedRange={usableFocusedRange}
        />
      </div>
    </div>
  );
}

export default CollapsibleDateRangePicker;
