import classnames from 'classnames';
import { endOfDay, isAfter, isBefore, isSameDay, startOfDay } from 'date-fns';
import React from 'react';
import { CoreStyles } from '../../../styles';
import { ClearPreview, PreviewRange } from '../../../types';


type ComponentProps = {
  day: Date;
  styles: CoreStyles;
  previewRange?: PreviewRange | ClearPreview;
}
const Preview: React.FC<ComponentProps> = (props) => {
  const { previewRange, day, styles } = props;

  if (!previewRange) return null;

  const startDate = previewRange.startDate ? endOfDay(previewRange.startDate) : null;
  const endDate = previewRange.endDate ? startOfDay(previewRange.endDate) : null;
  const isInRange = (!startDate || isAfter(day, startDate))
    && (!endDate || isBefore(day, endDate));
  const isStartEdge = !isInRange && !!startDate && isSameDay(day, startDate);
  const isEndEdge = !isInRange && !!endDate && isSameDay(day, endDate);

  return (
    <span
      className={classnames({
        [styles.dayStartPreview]: isStartEdge,
        [styles.dayInPreview]: isInRange,
        [styles.dayEndPreview]: isEndEdge,
      })}
      style={{ color: previewRange.color }}
    />
  );
}

export default Preview;