import classnames from 'classnames';
import { isSameDay, isBefore, endOfDay, startOfDay, isAfter } from 'date-fns';
import React from 'react';
import { InRange } from '..';
import { CoreStyles } from '../../../styles';
import { DisplayMode, MaybeEmptyRange } from '../../../types';
import { colorOpacity } from '../../../utils';

type ComponentProps = { styles: CoreStyles, ranges: MaybeEmptyRange[]; day: Date; displayMode: DisplayMode; date?: Date; color?: string; isComplete: boolean; };

const Selection: React.FC<ComponentProps> = (props) => {

  const { styles, ranges, day, displayMode, date, color, isComplete } = props;
  if (displayMode === 'date') {
    const isSelected = date && isSameDay(day, date);
    return isSelected ? (
      <span className={styles.selected} style={{ color }} />
    ) : null;
  }

  const inRanges = ranges.reduce((result: InRange[], range: MaybeEmptyRange) => {
    const st = range.startDate;
    const en = range.endDate;
    const [start, end] = (st && en && isBefore(en, st)) ? [en, st] : [st, en];
    const startDate = start ? endOfDay(start) : null;
    const endDate = end ? startOfDay(end) : null;
    const isInRange =
      (!startDate || isAfter(day, startDate)) && (!endDate || isBefore(day, endDate));
    const isStartEdge = !isInRange && !!startDate && isSameDay(day, startDate);
    const isEndEdge = !isInRange && !!endDate && isSameDay(day, endDate);
    if (isInRange || isStartEdge || isEndEdge) {
      return [
        ...result,
        {
          isStartEdge,
          isEndEdge: isEndEdge,
          isInRange,
          ...range,
        },
      ];
    }
    return result;
  }, []);

  return (
    <>
      {inRanges.map((range, i) => (
      <span
        key={i}
        className={classnames({
          [styles.startEdge]: range.isStartEdge,
          [styles.endEdge]: range.isEndEdge,
          [styles.inRange]: range.isInRange,
        })}
        style={{ color: colorOpacity((range.color || color || 'rgb(61, 145, 255)'), isComplete ? 1 : 0.5) }}
      />
    ))}
    </>
  );

}

export default Selection;