import React, { useState } from 'react';
import styles from '../../styles';
import { defaultInputRanges, defaultStaticRanges, defaultInputRangesGen, defaultStaticRangesGen, DEFAULT_WEEK_STARTS_ON, REFERENCE_DATE } from '../../defaultRanges';
import InputRangeField from '../InputRangeField';
import classnames from 'classnames';
import { InputRange, InputRangeWihLabel, NotFullyEmptyRange, RangeFocus, StaticRange, WeekStartsOn, ClearPreview, PreviewRange } from '../../types';
import StaticRanges, { handleRangeChangeGen, StaticRangesHandleRangeChangeProps } from '../StaticRanges';

type ComponentProps = StaticRangesHandleRangeChangeProps & {
  className?: string;
  footerContent?: JSX.Element;
  headerContent?: JSX.Element;
  inputRanges?: InputRangeWihLabel[];
  onPreviewChange?: (r?: PreviewRange | ClearPreview) => void;
  rangeColors?: string[];
  renderStaticRangeLabel?: (r: StaticRange) => JSX.Element;
  staticRanges?: StaticRange[];
  weekStartsOn?: WeekStartsOn;
}
export type DefinedRangeCP = ComponentProps;

type DefaultComponentProps = StaticRangesInputRanges & {
  ranges: NotFullyEmptyRange[];
  rangeColors: string[];
  focusedRange: RangeFocus;
  weekStartsOn: WeekStartsOn;
};
export type DefinedRangeDCP = DefaultComponentProps;

const defaultProps: DefaultComponentProps = {
  ranges: [],
  staticRanges: defaultStaticRanges,
  inputRanges: defaultInputRanges,
  rangeColors: ['#3d91ff', '#3ecf8e', '#fed14c'],
  focusedRange: [0, 0],
  weekStartsOn: DEFAULT_WEEK_STARTS_ON,
};

type StaticRangesInputRanges = {
  staticRanges: StaticRange[];
  inputRanges: InputRangeWihLabel[];
}

const getRangeOptionValue = (option: InputRange, allProps: ComponentProps) => {
    const { ranges = [], focusedRange = [] } = allProps;

    if (typeof option.getCurrentValue !== 'function') return '';

    const selectedRange = (focusedRange[0] && ranges[focusedRange[0]]) || {};
    return option.getCurrentValue(selectedRange) || '';
  }

const DefinedRange: React.FC<ComponentProps> = (props) => {
  const allProps: ComponentProps = { ...defaultProps, ...props };

  const weekStartsOn = allProps.weekStartsOn !== undefined && allProps.weekStartsOn || DEFAULT_WEEK_STARTS_ON;
  // commented out by g because unused
  // const [rangeOffset, setRangeOffset] = useState<number>(0);
  // const [focusedInput, setFocusedInput] = useState<number>(-1);
  const [rangesRespectingWeekStartsOn,] = useState<StaticRangesInputRanges>((allProps.weekStartsOn !== undefined && allProps.weekStartsOn !== DEFAULT_WEEK_STARTS_ON)
    ? {
      staticRanges: defaultStaticRangesGen({ weekStartsOn, referenceDate: REFERENCE_DATE || new Date() }),
      inputRanges: defaultInputRangesGen({ weekStartsOn, referenceDate: REFERENCE_DATE || new Date() }),
    }
    : {
      staticRanges: allProps.staticRanges || defaultStaticRanges,
      inputRanges: allProps.inputRanges || defaultInputRanges,
    }
  );

  const {
    className,
    footerContent,
    headerContent,
    onPreviewChange,
    rangeColors,
    ranges,
    renderStaticRangeLabel,
  } = allProps;

  const {
    inputRanges,
    staticRanges,
  } = rangesRespectingWeekStartsOn;

  const handleRangeChange = handleRangeChangeGen(allProps);

  return (
    <div className={classnames(styles.definedRangesWrapper, className)}>
      {headerContent}
      <StaticRanges
        ranges={ranges}
        staticRanges={staticRanges}
        onPreviewChange={onPreviewChange}
        rangeColors={rangeColors}
        renderStaticRangeLabel={renderStaticRangeLabel}
        handleRangeChange={handleRangeChange}
      />
      <div className={styles.inputRanges}>
        {inputRanges.map((rangeOption, i) => (
          <InputRangeField
            key={i}
            styles={styles}
            label={rangeOption.label}
            // commented out by g because unused
            // onFocus={() => { setFocusedInput(i), setRangeOffset(0) }}
            // onBlur={() => setRangeOffset(0)}
            onFocus={() => {}}
            onBlur={() => {}}
            onChange={value => handleRangeChange(rangeOption.range(value, allProps))}
            value={getRangeOptionValue(rangeOption, allProps)}
          />
        ))}
      </div>
      {footerContent}
    </div>
  );
}

export default DefinedRange;
