import classnames from 'classnames';
import React from 'react';
import { CLEAR_PREVIEW } from '../../..';
import styles from '../../../styles';
import { ClearPreview, hasRangeGen, isNotFullyEmptyRange, MaybeEmptyRange, NotFullyEmptyRange, PreviewRange, RangeFocus, StaticRange, WithRangeCallback } from '../../../types';

type ComponentProps = {
  focusedRange?: RangeFocus;
  focusedRangeIndex: number;
  handleRangeChange: (range: MaybeEmptyRange, allProps: ComponentProps) => void;
  onChange?: (keyedRange: { [k: string]: MaybeEmptyRange; }) => void;
  onPreviewChange?: (r?: PreviewRange | ClearPreview) => void;
  rangeColors?: string[];
  ranges?: NotFullyEmptyRange[];
  renderStaticRangeLabel?: (r: StaticRange) => JSX.Element;
  selectedRange?: MaybeEmptyRange;
  staticRange: StaticRange;
}

const StaticRangeButton: React.FC<ComponentProps> = (props) => {
  const { staticRange, renderStaticRangeLabel, selectedRange, focusedRangeIndex, handleRangeChange, rangeColors, onPreviewChange} = props;

  if (staticRange.hasCustomRendering && !renderStaticRangeLabel) {
    throw new Error('You should provide a renderStaticRangeLabel function when setting staticRange.hasCustomRendering = true');
  }
  if (!staticRange.label && !renderStaticRangeLabel) {
    throw new Error('Either provide a range with a label property or a renderStaticRangeLabel function to this component');
  }
  const labelContent = renderStaticRangeLabel && staticRange.hasCustomRendering
    ? renderStaticRangeLabel(staticRange)
    : staticRange.label;
  const actualStaticRange = hasRangeGen(staticRange) ? staticRange.range(props) : staticRange.range;

  if (!isNotFullyEmptyRange(actualStaticRange)) {
    console.log('staticRange: ', staticRange);
    console.log('range: ', staticRange.range);
    console.log('call.range()', (staticRange as WithRangeCallback).range());
    console.log(actualStaticRange);
    throw new Error('Expecting range to be a NotFullyEmptyRange, but found something different, possibly an empty range');
  }

  return (
    <button
      type="button"
      className={classnames(styles.staticRange, {
        [styles.staticRangeSelected]: Boolean(selectedRange),
      })}
      style={{
        color: selectedRange
          ? selectedRange.color || (rangeColors && rangeColors[focusedRangeIndex])
          : undefined,
      }}
      onClick={() => handleRangeChange(actualStaticRange, props)}
      onFocus={() => onPreviewChange && onPreviewChange(actualStaticRange)}
      onMouseOver={() =>
        onPreviewChange && onPreviewChange(actualStaticRange)
      }
      onMouseLeave={() => {
        onPreviewChange && onPreviewChange(CLEAR_PREVIEW);
      }}>
      <span tabIndex={-1} className={styles.staticRangeLabel}>
        {labelContent}
      </span>
    </button>
  );
}

export default StaticRangeButton;
