import React from 'react';
import { mount, shallow } from 'enzyme';

import StaticRanges from '.';
import { StaticRange, WithRangeOrRangeGen } from '../../types';
import { getDummyRange, createStaticRanges  } from '../../defaultRanges';


type StaticRangesProps = ({ label: string; } | { id: string; }) & { hasCustomRendering?: boolean; }
function fillUp<T extends StaticRangesProps>(sr: T): T &  WithRangeOrRangeGen {
  return {
    ...sr,
    range: getDummyRange,
  };
}

describe('StaticRanges tests', () => {
  test('Should call "renderStaticRangeLabel" callback correct amount of times according to the "hasCustomRendering" option', () => {
    const renderStaticRangeLabel = jest.fn();
    const staticRanges = createStaticRanges([
      {
        label: 'Dynamic Label',
        hasCustomRendering: true,
      },
      {
        label: 'Static Label',
      },
      {
        label: 'Hede',
        hasCustomRendering: true,
      },
    ].map(fillUp));
    mount(
      <StaticRanges
        staticRanges={staticRanges}
        renderStaticRangeLabel={renderStaticRangeLabel}
      />
    );

    expect(renderStaticRangeLabel).toHaveBeenCalledTimes(2);
  });

  test('Should render dynamic static label contents correctly', () => {
    const renderItalicLabelContent = () => (
      <i className={'italic-label-content'}>{'Italic Content'}</i>
    );
    const renderBoldLabelContent = () => <b className={'bold-label-content'}>{'Bold Content'}</b>;
    const renderSomethingElse = () => <img className={'random-image'} />;

    const renderStaticRangeLabel = function(staticRange: StaticRange): JSX.Element {
      let result;

      if (staticRange.id === 'italic') {
        result = renderItalicLabelContent();
      } else if (staticRange.id === 'bold') {
        result = renderBoldLabelContent();
      } else {
        result = renderSomethingElse();
      }

      return result;
    };

    const wrapper = shallow(
      <StaticRanges
        staticRanges={createStaticRanges([
          {
            id: 'italic',
            hasCustomRendering: true,
          },
          {
            label: 'Static Label',
          },
          {
            id: 'whatever',
            hasCustomRendering: true,
          },
          {
            id: 'bold',
            hasCustomRendering: true,
          },
        ].map(fillUp))}
        renderStaticRangeLabel={renderStaticRangeLabel}
      />
    );

    expect(wrapper).toMatchSnapshot();
  });
});
